@@ -10,7 +10,7 @@
 {% endif %}
 #define DISTRHO_PLUGIN_NUM_INPUTS      {{num_input_channels}}
 #define DISTRHO_PLUGIN_NUM_OUTPUTS     {{num_output_channels}}
-#define DISTRHO_PLUGIN_IS_SYNTH        {{1 if num_input_channels == 0 and num_output_channels > 0 else 1}}
+#define DISTRHO_PLUGIN_IS_SYNTH        {{1 if num_output_channels > 0 and meta.midi_input else 0}}
 #define DISTRHO_PLUGIN_HAS_UI          0
 #define DISTRHO_PLUGIN_IS_RT_SAFE      1
 #define DISTRHO_PLUGIN_WANT_PROGRAMS   0
